function dots_y = CFU_model_sim(X,U,D) 
n_x = 10; % Number of vertically discretized control volumes, hence n_x + 2 nodes one each at the two boundaries x = 0 and x = L
% Control volumes start from the bottom. Hence x = 0 to x = L/n_x is the first control volume
scaling_factor = 1e10;
%x = xu(1:35);
x = X;
%u = xu(36:38);
u = U;
%z_float = u(1);
%z_out = u(2);
%z_reject = u(3);

F_in = D(1);
ppm_in = D(2);

F_in = F_in/3600;
e_in = ppm_in*1e-6;

% Allocation of states
n_fb = x(1:n_x)*scaling_factor;
n_d = x(n_x+1:2*n_x)*scaling_factor;
n_lb = x(2*n_x+1:3*n_x)*scaling_factor;
alpha_l = x(3*n_x+1);
P = x(3*n_x+2)*1e5;
n_d_bottom = x(3*n_x+3)*scaling_factor;
n_fb_top = x(3*n_x+4)*scaling_factor;
n_lb_top = x(3*n_x+5)*scaling_factor;

% Dimensions
V = 3.2; % m^3 volume of the CFU main separation zone volume
R = 1.26/2; % Radius of CFU vessel in meter
L = V/pi/R^2;
dL = L/(n_x+2);

% Operating data
db = 200e-6; % Gas bubble size in meter
dd = 25e-6; % Oil droplet size in meter
V_fb = pi*db^3/6; % volume of the bubble at P_bottom
V_d = pi*dd^3/6;
Ec = (dd/db)^2; % Collision efficiency due to Flint and Howarth
k =  4e-11; % Loading rate constant [m^-3s^-1] Tuning parameter

% Fluid data and constants
rho_w = 1000;
rho_o = 900;
P_supply = 2e5;
P_atm = 1e5;
M_g = 16e-3; % Molecular mass of methane in kg/mol
R_g = 8.314; % Universal gas cosntant
T = 300; % Operating Temperature in Kelvin
rho_g = P * M_g / R_g/T;

mu_w = 8.9e-4;
g = 9.81;
Cd_top = 0.0002*3/5*0.5543/0.3;
Cd_bottom = 0.002*32/25;
Cd_float = 6/5*9/25*7e-06;
 
%P_bottom = P + rho_w*alpha_l*g*L;
%P_bottom = P;
% rho_g_bottom = P_bottom * M_g / R_g/T;
% rho_out = rho_w*(1-n_d_bottom*V_d) + rho_o*(n_d_bottom*V_d);

%F_float = 0.0012;
%F_float = z_float*Cd_float*sqrt(2/rho_g_bottom*max(P_supply-P_bottom,0));
F_float = u(1)/3600;
%F_out = z_out*Cd_bottom*sqrt(2/rho_out*max(P_bottom-P_atm,0));
F_out = u(2)/3600;

% Velocities
%v_bulk = F_out/pi/R^2/(1-V/(pi*R^2)*(sum(n_fb)*(pi*db^2/4)+sum(n_d)*(pi*dd^2/4)+sum(n_lb)*(pi*((dd^3+db^3)^(2/3))/4))/n_x);
v_bulk = F_out/pi/R^2/alpha_l;

%v_bulk = F_out/pi/R^2;
v_fb = (rho_w - rho_g)*g*db^2/18/mu_w -v_bulk;  % absolute up velocity
v_d  = -(rho_w - rho_o)*g*dd^2/18/mu_w + v_bulk; % absolute down velocity
v_lb = ((rho_w-rho_g)*V_fb+(rho_w-rho_o)*V_d)*g/3/pi/mu_w/((db^3+dd^3)^(1/3)) - v_bulk; % absolute up velocity
%v_d = v_fb;


% droplets at bottom control volume below everything else. in this control
% volume we dont have differential equations for any thing else, no loading
% happening here

n_d_dot_bottom =   (v_d*n_d(1) - (F_out/pi/R^2)*n_d_bottom)/dL;

% Bottom boundary conditions
i = 1;
load_rate = (k*Ec*n_fb(i)*n_d(i));
n_fb_dot(i) =  (F_float*(P_supply/P)/V_fb/(pi*R^2)-n_fb(i)*v_fb)/dL  - load_rate;
n_d_dot(i) =   v_d*(n_d(i+1)-n_d(i))/dL - load_rate;
n_lb_dot(i) =  (0-n_lb(i)*v_lb)/dL   + load_rate;
% n_fb_dot(i) =  (F_float/V_fb/(pi*R^2)-(n_fb(i)+n_fb(i+1))/2*v_fb)/dL  - load_rate(i);
% n_d_dot(i) =   v_d*((n_d(i+1)+n_d(i))/2-n_d(i))/dL - load_rate(i);
% n_lb_dot(i) =  (0-(n_lb(i)+n_lb(i+1))/2*v_lb)/dL   + load_rate(i);

% Differential equations for internal control volumes
for i = 2:n_x-1
load_rate = k*Ec*n_fb(i)*n_d(i);
% n_fb_dot(i) =  v_fb*((n_fb(i-1)+n_fb(i))/2-(n_fb(i)+n_fb(i+1))/2)/dL    -load_rate(i);
% n_d_dot(i) =   v_d*((n_d(i+1)+n_d(i))/2-(n_d(i)+n_d(i-1))/2)/dL       -load_rate(i);
% n_lb_dot(i) =  v_lb*((n_lb(i-1)+n_lb(i))/2-(n_lb(i)+n_lb(i+1))/2)/dL  +load_rate(i);
n_fb_dot(i) =  v_fb*(n_fb(i-1)-n_fb(i))/dL    -load_rate;
n_d_dot(i) =   v_d*((n_d(i+1))-(n_d(i)))/dL   -load_rate;
n_lb_dot(i) =  v_lb*(n_lb(i-1)-n_lb(i))/dL    +load_rate;

end

% Top boundary conditions
i = n_x;
load_rate = k*Ec*n_fb(i)*n_d(i);
n_fb_dot(i) = v_fb*(n_fb(i-1)-n_fb(i))/dL  -load_rate;
n_d_dot(i) = (F_in*e_in/V_d/(pi*R^2)-n_d(i)*v_d)/dL - load_rate;
n_lb_dot(i) = v_lb*(n_lb(i-1)-n_lb(i))/dL  + load_rate;
% n_fb_dot(i) = v_fb*((n_fb(i-1)+n_fb(i))/2-n_fb(i))/dL  -load_rate(i);
% n_d_dot(i) = (F_in*e_in/V_d/(pi*R^2)-(n_d(i)+n_d(i-1))/2*v_d)/dL - load_rate(i);
% n_lb_dot(i) = v_lb*((n_lb(i-1)+n_lb(i))/2-n_lb(i))/dL  + load_rate(i);

% Liquid hold-up and pressure calculation
alpha_gas_top = V_fb*(n_fb_top+n_lb_top);
alpha_oil_top = V_d*(n_lb_top);
%F_reject = z_reject*Cd_top*sqrt(2/(rho_o*alpha_oil_top + rho_w*(1-alpha_gas_top-alpha_oil_top)+rho_g*alpha_gas_top)*(P-P_atm));

F_reject = u(3)/3600;
F_reject_liq = F_reject*(1-alpha_gas_top);
%alpha_l_dot = Xdot(31);
alpha_l_dot = (F_in - F_out - F_reject_liq)/V;
V_l_dot = alpha_l_dot*V;
% P_dot = P*(V*alpha_l_dot+F_float - F_reject*alpha_gas_top)/(V*(1-alpha_l));
% P_dot = P*(F_float+F_in - F_reject-F_out)/(V*(1-alpha_l));
F_gas_out = alpha_gas_top*F_reject;
P_dot = (P*V_l_dot + (P_supply*F_float - P*F_gas_out))/V/(1-alpha_l);

% F_reject_oil = alpha_oil_top*F_reject;
%n_lb_reject = F_reject_oil/V_d;
%n_fb_reject = alpha_gas_top*F_reject*(P/P_bottom/V_fb) - n_lb_reject;

% F_reject_corrected = F_gas_out*P/P_bottom + F_reject_liq;

n_fb_dot_top =   (v_fb*n_fb(n_x) - F_reject/(pi*R^2)*n_fb_top)/dL;
%n_fb_dot_top =   (v_fb*n_fb(n_x) - n_fb_reject/(pi*R^2))/dL;
%n_fb_dot_top =   (v_fb*n_fb(n_x) - F_reject_corrected/(pi*R^2)*n_fb_top)/dL;

n_lb_dot_top =   (v_lb*n_lb(n_x) - F_reject/60*(pi*R^2)*n_lb_top)/dL;
% n_lb_dot_top =   (v_lb*n_lb(n_x) - n_lb_reject/(pi*R^2))/dL;
%n_lb_dot_top =   (v_lb*n_lb(n_x) - F_reject_corrected/(pi*R^2)*n_lb_top)/dL;

ppm_out = n_d_bottom*V_d*1e6;
F_reject_water = F_reject*(1-alpha_gas_top - alpha_oil_top)*3600;
n_dot_flotation = P_supply*F_float*3600*M_g/R_g/T;

% Purging the differential equations
dots = [n_fb_dot'/scaling_factor;n_d_dot'/scaling_factor;n_lb_dot'/scaling_factor; alpha_l_dot; P_dot/1e5; n_d_dot_bottom/scaling_factor; n_fb_dot_top/scaling_factor; n_lb_dot_top/scaling_factor]; 
outputs = [ppm_out; P/1e5; F_reject_water; F_out*3600; n_dot_flotation; alpha_gas_top; alpha_oil_top; F_reject*3600];
dots_y = [dots;outputs];