%% Initialize Parameters:
% Numbers:
nx = 9;                     % Number of horizontal control volumes
nz_o = 3;                   % Number of vertical control volumes oil
nz_w = 3;                   % Number of vertical control volumes water
nz_t = nz_o + nz_w;
ns_o = nz_o*nx*10;          % Number of states in oil.
ns_w = nz_w*nx*10;          % Number of states in water.
ns_tot = ns_o + ns_w + 3;   % Total number of states in model.
nd = 4;                     % Number of disturbances (F_g, F_l, e_in, d_A)
nu = 1;                     % Number of system inputs (Outflows)

% Separator sizes:
r = 2;                      % Radius of separator [m]
L = 15;                     % Lenght of separator [m]
h_w = r;                    % Height of weir [m]

% Other
R_gas = 8.314;              % Gas constant J/(K mol)
Mm_g = 0.01604;             % Molar mass of gas [kg/mol] 
rho_g = 49.7;               % Density gas [kg/m3]
rho_o = 831.5;              % Density oil [kg/m3]
rho_w = 1000;               % Density water [kg/m3]
mu_o = 0.001;               % Viscosity oil [kg/sm]
mu_w = 0.0005;              % Viscosity water [kg/sm]
T = 328.5;                  % Temperature [K]
k = ones(25,1)*1e-8;        % reaction rate constants of coalescence
n_adp = 1;                  % Adapting parameter stokes velocity
k_int_w = 0.5;              % Rate constant, water droplet to water
k_int_o = 0.5;              % Rate constant, oil droplet to oil
g_o = 0.99;                % Fraction of oil that goes to oil phase
g_w = 0.4;                 % Fraction of water that goes to water phase
g_o_2 = 0.999;
g_w_2 = 0.15;

% Setpoints
P_sp = 70;                  % Pressure [bar]
% hl_sp = h_w + 0.9*(2*r-h_w);% Liquid level [m]
% hlw_sp = 0.6*h_w;           % Water level [m]

% Disturbances:
F_in_val = [0.456,0.59]';   % Feed flow of gas and liquid [m3/s]
e_in_val = 0.15;            % Water cut in feed [-]
d_A_val = 150e-6;           % Diameter of water droplets in feed [m]
D_val = [F_in_val; e_in_val; d_A_val ]; 
    
% Input variables:
F_g_val = F_in_val(1);
F_o_val = F_in_val(2)*(1-e_in_val);
F_w_val = F_in_val(2)*e_in_val;
U_val = [F_g_val;F_o_val;F_w_val];
% In this steady state model the two liquid product flows are calculated
% in the model.
