function R = rateOfFormation(rho,k,rho_d)
% Calculates the rate of change in partial densities due to coalescence.
% rho:  Vector of partial densities of droplets (10 sizes)
% k:    Vector of 25 reaction rate constants
% The 25 different equations of possible coelescence reaction of 10 droplet 
% sizes are given in the N matrix.

% Author Sindre Johan Heggheim
% Date 03.06.2018
% Modified 12.06.2018

N = [ ...   5             10             15             20             25   
-2 -1 -1 -1 -1 -1 -1 -1 -1  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0;
 1 -1  0  0  0  0  0  0  0 -2 -1 -1 -1 -1 -1 -1  0  0  0  0  0  0  0  0  0;
 0  1 -1  0  0  0  0  0  0  0 -1  0  0  0  0  0 -2 -1 -1 -1 -1  0  0  0  0;
 0  0  1 -1  0  0  0  0  0  1  0 -1  0  0  0  0  0 -1  0  0  0 -2 -1 -1  0;
 0  0  0  1 -1  0  0  0  0  0  1  0 -1  0  0  0  0  0 -1  0  0  0 -1  0 -2;
 0  0  0  0  1 -1  0  0  0  0  0  1  0 -1  0  0  1  0  0 -1  0  0  0 -1  0;
 0  0  0  0  0  1 -1  0  0  0  0  0  1  0 -1  0  0  1  0  0 -1  0  0  0  0;
 0  0  0  0  0  0  1 -1  0  0  0  0  0  1  0 -1  0  0  1  0  0  1  0  0  0;
 0  0  0  0  0  0  0  1 -1  0  0  0  0  0  1  0  0  0  0  1  0  0  1  0  0;
 0  0  0  0  0  0  0  0  1  0  0  0  0  0  0  1  0  0  0  0  1  0  0  1  1;
];  % 10 sizes times 25 reactions

i = (1:10)';
V_A = (150e-6)^3*pi/6;
nd = rho./(V_A*i*rho_d); % number density

%temp = [1:9,2*(2:8),3*(3:7),4*(4:6),5*5]';

% k_d = k.*V_A*rho_d.*temp;
k_d = k;
r1   = nd(1)*nd(1:9).*k_d(1:9);
r2   = nd(2)*nd(2:8).*k_d(10:16);
r3   = nd(3)*nd(3:7).*k_d(17:21);
r4   = nd(4)*nd(4:6).*k_d(22:24);
r5   = nd(5)*nd(5).*k_d(25);
r = [r1;r2;r3;r4;r5]; % #/m3s
R = rho_d*V_A*i.*(N*r); % kg/m3s 
end%fun