function rate = rateOfFormation(rho,k)
% Calculates rate of change in partial density due to coalescence
% rho:  Vector of partial densities of droplets (10 sizes)
% k:    Vector of 25 reaction rate constants
% The 25 different coelescence reaction of 10 droplet sizes are given in 
% the N matrix.
N = [ ...   5             10             15             20             25   
-2 -1 -1 -1 -1 -1 -1 -1 -1  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0;
 1 -1  0  0  0  0  0  0  0 -2 -1 -1 -1 -1 -1 -1  0  0  0  0  0  0  0  0  0;
 0  1 -1  0  0  0  0  0  0  0 -1  0  0  0  0  0 -2 -1 -1 -1 -1  0  0  0  0;
 0  0  1 -1  0  0  0  0  0  1  0 -1  0  0  0  0  0 -1  0  0  0 -2 -1 -1  0;
 0  0  0  1 -1  0  0  0  0  0  1  0 -1  0  0  0  0  0 -1  0  0  0 -1  0 -2;
 0  0  0  0  1 -1  0  0  0  0  0  1  0 -1  0  0  1  0  0 -1  0  0  0 -1  0;
 0  0  0  0  0  1 -1  0  0  0  0  0  1  0 -1  0  0  1  0  0 -1  0  0  0  0;
 0  0  0  0  0  0  1 -1  0  0  0  0  0  1  0 -1  0  0  1  0  0  1  0  0  0;
 0  0  0  0  0  0  0  1 -1  0  0  0  0  0  1  0  0  0  0  1  0  0  1  0  0;
 0  0  0  0  0  0  0  0  1  0  0  0  0  0  0  1  0  0  0  0  1  0  0  1  1;
];  % 10 sizes times 25 reactions
r1   = rho(1)*rho(1:9).*k(1:9);
r2   = rho(2)*rho(2:8).*k(10:16);
r3   = rho(3)*rho(3:7).*k(17:21);
r4   = rho(4)*rho(4:6).*k(22:24);
r5   = rho(5)*rho(5).*k(25);
r = [r1;r2;r3;r4;r5];
rate=(N*r).*(1:10)'; % rate of formation with the relative changes in rho
end%fun