%% Step in Pressure setpoint:
load('init_simParam')
run('init_param')
open('separationSystem_bulk')
set_param('separationSystem_bulk', 'StopTime', '3*60')
d_time = 1e6*[1,1,1];

Y1sp_time = [1*60,1e6,1e6];
Y1.step=[70/Y1.sp(1), 0.95, 1.05];
sim('separationSystem_bulk')

%% Plots:
close all; clc;
cvt = gs1_Y.time; 
cv_1 = gs1_Y.signals.values(:,1);
cv_2 = gs1_Y.signals.values(:,2);
cv_3 = gs1_Y.signals.values(:,3);
cv_4 = gs1_Y.signals.values(:,4);
cv_5 = gs1_Y.signals.values(:,5);

mvt = gs1_U.time;
mv_1 = gs1_U.signals.values(:,1);
mv_2 = gs1_U.signals.values(:,2);
mv_3 = gs1_U.signals.values(:,3);

dt = simD.time;
d_1 = simD.signals.values(:,1);
d_2 = simD.signals.values(:,2);
d_3 = simD.signals.values(:,3);

xtv = [ 0, 1, 2, 3 ]*60;
xtl = {'0','1','2','3'};
fig = figure('DefaultAxesPosition', [0.05, 0.05, 0.9, 0.9]);
subplot(4,3,1); 
plot(cvt,cv_1); ylabel('Pressure [bar]');
ylim([min(cv_1)-0.1*(max(cv_1)-min(cv_1)),max(cv_1)+0.1*(max(cv_1)-min(cv_1))])
xlim([0,max(cvt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,2); 
plot(cvt,cv_2); ylabel('Liquid level [m]');
% ylim([min(cv_2)-0.1*(max(cv_2)-min(cv_2)),max(cv_2)+0.1*(max(cv_2)-min(cv_2))])
ylim([3,4])
xlim([0,max(cvt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,3); 
plot(cvt,cv_3); ylabel('Water level [m]');
% ylim([min(cv_3)-0.1*(max(cv_3)-min(cv_3)),max(cv_3)+0.1*(max(cv_3)-min(cv_3))])
ylim([1.5,2])
xlim([0,max(cvt)]);  xticks(xtv); xticklabels(xtl);

cv_4=100*cv_4;
subplot(4,3,5); 
plot(cvt,cv_4); ylabel('WiO [%]'); 
% ylim([min(cv_4)-0.1*(max(cv_4)-min(cv_4)),max(cv_4)+0.1*(max(cv_4)-min(cv_4))])
ylim([min(cv_4)-0.1,max(cv_4)+0.1])
xlim([0,max(cvt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,6); 
plot(cvt,cv_5); ylabel('OiW [ppm]');
% ylim([min(cv_5)-0.1*(max(cv_5)-min(cv_5)),max(cv_5)+0.1*(max(cv_5)-min(cv_5))])
ylim([min(cv_5)-10,max(cv_5)+10])
xlim([0,max(cvt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,7); 
plot(mvt,mv_1); ylabel('Gas product [m^3s^{-1}]');
% ylim([min(mv_1)-0.1*(max(mv_1)-min(mv_1)),max(mv_1)+0.1*(max(mv_1)-min(mv_1))])
xlim([0,max(mvt)]); xticks(xtv); xticklabels(xtl);
 
subplot(4,3,8); 
plot(mvt,mv_2); ylabel('Oil product [m^3s^{-1}]');
% ylim([min(mv_2)-0.1*(max(mv_2)-min(mv_2)),max(mv_2)+0.1*(max(mv_2)-min(mv_2))])
xlim([0,max(mvt)]);xticks(xtv); xticklabels(xtl);

subplot(4,3,9); 
plot(mvt,mv_3); ylabel('Water product [m^3s^{-1}]');
% ylim([min(mv_3)-0.1*(max(mv_3)-min(mv_3)),max(mv_3)+0.1*(max(mv_3)-min(mv_3))])
xlim([0,max(mvt)]); xticks(xtv); xticklabels(xtl);


subplot(4,3,10); 
plot(dt,d_1); ylabel('Gas feed [m^3s^{-1}]'); xlabel('Time [min]');
ylim([min(d_1)-0.01, max(d_1)+0.01])
xlim([0,max(dt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,11); plot(dt,d_2); ylabel('Liquid feed [m^3s^{-1}]');xlabel('Time [min]');
ylim([min(d_2)-0.01, max(d_2)+0.01])
xlim([0,max(dt)]); xticks(xtv); xticklabels(xtl);


subplot(4,3,12);
d_3 = 100*d_3; plot(dt,d_3); ylabel('Feed water cut [%]');xlabel('Time [min]');
ylim([min(d_3)-0.01, max(d_3)+0.01])
xlim([0,max(dt)]); xticks(xtv); xticklabels(xtl);
% 
% 
fig=setFigProps(fig);
% saveas(fig,'GS1sim_P_step','png');
% saveas(fig,'GS1sim_P_step','epsc');


%% Run step in liquid level setpoint
Y1sp_time = [1e6,1*60,1e6];
Y1.step=[70/Y1.sp(1), 0.95, 1.05];
set_param('separationSystem_bulk', 'StopTime', '30*60')
sim('separationSystem_bulk')

%% plots:
close all; clc;
cvt = gs1_Y.time; 
cv_1 = gs1_Y.signals.values(:,1);
cv_2 = gs1_Y.signals.values(:,2);
cv_3 = gs1_Y.signals.values(:,3);
cv_4 = gs1_Y.signals.values(:,4);
cv_5 = gs1_Y.signals.values(:,5);

mvt = gs1_U.time;
mv_1 = gs1_U.signals.values(:,1);
mv_2 = gs1_U.signals.values(:,2);
mv_3 = gs1_U.signals.values(:,3);

dt = simD.time;
d_1 = simD.signals.values(:,1);
d_2 = simD.signals.values(:,2);
d_3 = simD.signals.values(:,3);

xtv = [ 0, 10, 20, 30 ]*60;
xtl = {'0','10','20','30'};
fig = figure('DefaultAxesPosition', [0.05, 0.05, 0.9, 0.9]);
subplot(4,3,1); 
plot(cvt,cv_1); ylabel('Pressure [bar]');
ylim([min(cv_1)-0.1*(max(cv_1)-min(cv_1)),max(cv_1)+0.1*(max(cv_1)-min(cv_1))])
xlim([0,max(cvt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,2); 
plot(cvt,cv_2); ylabel('Liquid level [m]');
% ylim([min(cv_2)-0.1*(max(cv_2)-min(cv_2)),max(cv_2)+0.1*(max(cv_2)-min(cv_2))])
ylim([3,4])
xlim([0,max(cvt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,3); 
plot(cvt,cv_3); ylabel('Water level [m]');
% ylim([min(cv_3)-0.1*(max(cv_3)-min(cv_3)),max(cv_3)+0.1*(max(cv_3)-min(cv_3))])
ylim([1.75,1.85])
xlim([0,max(cvt)]);  xticks(xtv); xticklabels(xtl);

cv_4=100*cv_4;
subplot(4,3,5); 
plot(cvt,cv_4); ylabel('WiO [%]'); 
ylim([min(cv_4)-0.1*(max(cv_4)-min(cv_4)),max(cv_4)+0.1*(max(cv_4)-min(cv_4))])
% ylim([min(cv_4)-0.1,max(cv_4)+0.1])
xlim([0,max(cvt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,6); 
plot(cvt,cv_5); ylabel('OiW [ppm]');
ylim([min(cv_5)-0.1*(max(cv_5)-min(cv_5)),max(cv_5)+0.1*(max(cv_5)-min(cv_5))])
% ylim([min(cv_5)-10,max(cv_5)+10])
xlim([0,max(cvt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,7); 
plot(mvt,mv_1); ylabel('Gas product [m^3s^{-1}]');
ylim([min(mv_1)-0.1*(max(mv_1)-min(mv_1)),max(mv_1)+0.1*(max(mv_1)-min(mv_1))])
xlim([0,max(mvt)]); xticks(xtv); xticklabels(xtl);
 
subplot(4,3,8); 
plot(mvt,mv_2); ylabel('Oil product [m^3s^{-1}]');
% ylim([min(mv_2)-0.1*(max(mv_2)-min(mv_2)),max(mv_2)+0.1*(max(mv_2)-min(mv_2))])
xlim([0,max(mvt)]);xticks(xtv); xticklabels(xtl);

subplot(4,3,9); 
plot(mvt,mv_3); ylabel('Water product [m^3s^{-1}]');
ylim([min(mv_3)-0.1*(max(mv_3)-min(mv_3)),max(mv_3)+0.1*(max(mv_3)-min(mv_3))])
ylim([min(mv_3)-0.01,max(mv_3)+0.01])

xlim([0,max(mvt)]); xticks(xtv); xticklabels(xtl);


subplot(4,3,10); 
plot(dt,d_1); ylabel('Gas feed [m^3s^{-1}]'); xlabel('Time [min]');
ylim([min(d_1)-0.01, max(d_1)+0.01])
xlim([0,max(dt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,11); plot(dt,d_2); ylabel('Liquid feed [m^3s^{-1}]');xlabel('Time [min]');
ylim([min(d_2)-0.01, max(d_2)+0.01])
xlim([0,max(dt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,12);
d_3 = 100*d_3; plot(dt,d_3); ylabel('Feed water cut [%]');xlabel('Time [min]');
ylim([min(d_3)-0.01, max(d_3)+0.01])
xlim([0,max(dt)]); xticks(xtv); xticklabels(xtl);

fig=setFigProps(fig);
% saveas(fig,'GS1sim_hl_step','png');
% saveas(fig,'GS1sim_hl_step','epsc');


%% Run step in waterlevel setpoint.
Y1sp_time = [1e6,1e6,1*60];
Y1.step=[70/Y1.sp(1), 0.95, 1.05];
set_param('separationSystem_bulk', 'StopTime', '30*60')
sim('separationSystem_bulk')

%%
close all; clc;
cvt = gs1_Y.time; 
cv_1 = gs1_Y.signals.values(:,1);
cv_2 = gs1_Y.signals.values(:,2);
cv_3 = gs1_Y.signals.values(:,3);
cv_4 = gs1_Y.signals.values(:,4);
cv_5 = gs1_Y.signals.values(:,5);

mvt = gs1_U.time;
mv_1 = gs1_U.signals.values(:,1);
mv_2 = gs1_U.signals.values(:,2);
mv_3 = gs1_U.signals.values(:,3);

dt = simD.time;
d_1 = simD.signals.values(:,1);
d_2 = simD.signals.values(:,2);
d_3 = simD.signals.values(:,3);

xtv = [ 0, 10, 20, 30 ]*60;
xtl = {'0','10','20','30'};
fig = figure('DefaultAxesPosition', [0.05, 0.05, 0.9, 0.9]);
subplot(4,3,1); 
plot(cvt,cv_1); ylabel('Pressure [bar]');
ylim([min(cv_1)-1,max(cv_1)+1])
xlim([0,max(cvt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,2); 
plot(cvt,cv_2); ylabel('Liquid level [m]');
% ylim([min(cv_2)-0.1*(max(cv_2)-min(cv_2)),max(cv_2)+0.1*(max(cv_2)-min(cv_2))])
ylim([3,4])
xlim([0,max(cvt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,3); 
plot(cvt,cv_3); ylabel('Water level [m]');
ylim([min(cv_3)-0.1*(max(cv_3)-min(cv_3)),max(cv_3)+0.1*(max(cv_3)-min(cv_3))])
% ylim([1.75,1.85])
xlim([0,max(cvt)]);  xticks(xtv); xticklabels(xtl);

cv_4=100*cv_4;
subplot(4,3,5); 
plot(cvt,cv_4); ylabel('WiO [%]'); 
ylim([min(cv_4)-0.1*(max(cv_4)-min(cv_4)),max(cv_4)+0.1*(max(cv_4)-min(cv_4))])
% ylim([min(cv_4)-0.1,max(cv_4)+0.1])
xlim([0,max(cvt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,6); 
plot(cvt,cv_5); ylabel('OiW [ppm]');
ylim([min(cv_5)-0.1*(max(cv_5)-min(cv_5)),max(cv_5)+0.1*(max(cv_5)-min(cv_5))])
% ylim([min(cv_5)-10,max(cv_5)+10])
xlim([0,max(cvt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,7); 
plot(mvt,mv_1); ylabel('Gas product [m^3s^{-1}]');
ylim([min(mv_1)-0.1*(max(mv_1)-min(mv_1)),max(mv_1)+0.1*(max(mv_1)-min(mv_1))])
xlim([0,max(mvt)]); xticks(xtv); xticklabels(xtl);
 
subplot(4,3,8); 
plot(mvt,mv_2); ylabel('Oil product [m^3s^{-1}]');
% ylim([min(mv_2)-0.1*(max(mv_2)-min(mv_2)),max(mv_2)+0.1*(max(mv_2)-min(mv_2))])
xlim([0,max(mvt)]);xticks(xtv); xticklabels(xtl);

subplot(4,3,9); 
plot(mvt,mv_3); ylabel('Water product [m^3s^{-1}]');
ylim([min(mv_3)-0.1*(max(mv_3)-min(mv_3)),max(mv_3)+0.1*(max(mv_3)-min(mv_3))])
ylim([min(mv_3)-0.01,max(mv_3)+0.01])

xlim([0,max(mvt)]); xticks(xtv); xticklabels(xtl);


subplot(4,3,10); 
plot(dt,d_1); ylabel('Gas feed [m^3s^{-1}]'); xlabel('Time [min]');
ylim([min(d_1)-0.01, max(d_1)+0.01])
xlim([0,max(dt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,11); plot(dt,d_2); ylabel('Liquid feed [m^3s^{-1}]');xlabel('Time [min]');
ylim([min(d_2)-0.01, max(d_2)+0.01])
xlim([0,max(dt)]); xticks(xtv); xticklabels(xtl);

subplot(4,3,12);
d_3 = 100*d_3; plot(dt,d_3); ylabel('Feed water cut [%]');xlabel('Time [min]');
ylim([min(d_3)-0.01, max(d_3)+0.01])
xlim([0,max(dt)]); xticks(xtv); xticklabels(xtl);

fig=setFigProps(fig);
saveas(fig,'GS1sim_hlw_step','png');
saveas(fig,'GS1sim_hlw_step','epsc');



%% Possible cascade controller for OiW?
Y1sp_time = [1e6,1e6,1*60];
Y1.step=[70/Y1.sp(1), 0.95, 1.05];
set_param('separationSystem_bulk', 'StopTime', '30*60')
sim('separationSystem_bulk')
%% 
close all; clc;
cvt = gs1_Y.time;
cv_1 = gs1_Y.signals.values(:,1);
cv_2 = gs1_Y.signals.values(:,2);
cv_3 = gs1_Y.signals.values(:,3);
cv_4 = gs1_Y.signals.values(:,4);
cv_5 = gs1_Y.signals.values(:,5);

yo = abs((min(cv_5)-cv_5(1)));
yend = abs(cv_5(end)-cv_5(1));
Overshoot = (yo-yend)/yend

mvt = gs1_U.time;
mv_1 = gs1_U.signals.values(:,1);
mv_2 = gs1_U.signals.values(:,2);
mv_3 = gs1_U.signals.values(:,3);

dt = simD.time;
d_1 = simD.signals.values(:,1);
d_2 = simD.signals.values(:,2);
d_3 = simD.signals.values(:,3);

fig = figure('DefaultAxesPosition', [0.05, 0.05, 0.9, 0.94]);
subplot(3,1,1); 
plot(cvt,cv_5); ylabel('OiW [ppm]');
ylim([min(cv_5)-0.1*(max(cv_5)-min(cv_5)),max(cv_5)+0.1*(max(cv_5)-min(cv_5))])

subplot(3,1,2);  
plot(cvt,cv_3); ylabel('Water level [m]');
ylim([min(cv_3)-0.1*(max(cv_3)-min(cv_3)),max(cv_3)+0.1*(max(cv_3)-min(cv_3))])
hold on; cv3_sp = gs1_Ysp.signals.values(:,3); cv3_spt = gs1_Ysp.time;
plot(cv3_spt,cv3_sp,':'); 
legend('h_{lw}','h_{lw,sp}','Location','SouthEast')

subplot(3,1,3);
plot(mvt,mv_3); ylabel('Water product [m^3s^{-1}]');xlabel('Time [min]');
ylim([min(mv_3)-0.1*(max(mv_3)-min(mv_3)),max(mv_3)+0.1*(max(mv_3)-min(mv_3))])

fig = setFigProps2(fig);
saveas(fig,'GS1sim_cascade','png');
saveas(fig,'GS1sim_cascade','epsc');
