function fig = setFigProps(fig,subplotpos)
if nargin == 1
    subplotpos = '0x0'; %2x2 is the possible option
end%if

% Adjust:
figProps.Color = [1 1 1]; % Backgroundcolor
fontProps.FontName = 'times';
fontProps.FontSize = 12;
PlotLineWidth = 1.5;
papersize = [21.0, 29.7]; % A4 [cm]
lr_margins = [2.5, 2.5]; % left and right margin [cm]
tb_margins = [2.7, 3.0]; % top and bottom margin [cm]
% figRatio = 16/9;

% Set parameters:
figProps.Units = 'centimeters';
figProps.PaperUnits = 'centimeters';
width = papersize(1)-sum(lr_margins);
% height = width/figRatio
height = (papersize(2)-sum(tb_margins))*0.8; 
figProps.papersize = papersize; 
figProps.paperposition = [0,0,width,height];
figProps.position = [1,1.1,width,height];


h = findobj(fig.Children,'Type','line');
for i = 1:size(h,1)
    h(i).LineWidth = PlotLineWidth;
end%for

set(fig.Children,fontProps);
set(fig,figProps);


% Adjust subplots:
if subplotpos == '2x2'  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
s = findobj(allchild(fig), 'flat', 'Type', 'axes');
cellPos = get(s,'OuterPosition');
pos = cell2mat(cellPos);
x = sort(pos(:,1));
y = sort(pos(:,2));

for i = 1:size(s,1) % Push the outerposition
if     (pos(i,1)==x(1) || pos(i,1)==x(2)) && (pos(i,2)==y(1)||pos(i,2)==y(2)) % left down  
    set(s(i),'OuterPosition',[0,0,0.5,0.5]);
    i_ld = i;
elseif (pos(i,1)==x(1) || pos(i,1)==x(2)) && (pos(i,2)==y(3)||pos(i,2)==y(4)) % left up  
    set(s(i),'OuterPosition',[0,0.5,0.5,0.5]);
    i_lu = i;
elseif (pos(i,1)==x(3) || pos(i,1)==x(4)) && (pos(i,2)==y(3)||pos(i,2)==y(4)) % right up  
    set(s(i),'OuterPosition',[0.5,0.5,0.5,0.5]);
    i_ru = i;
elseif (pos(i,1)==x(3) || pos(i,1)==x(4)) && (pos(i,2)==y(1)||pos(i,2)==y(2)) % right down  
    set(s(i),'OuterPosition',[0.5,0,0.5,0.5]);
    i_rd = i;
end%if
end%for

pos2 = cell2mat(get(s,'Position'));
wh = [min(pos2(:,3)),min(pos2(:,4))];
P_ld = pos2(i_ld,1);
P_lu = pos2(i_lu,1);
P_ru = pos2(i_ru,1);
P_rd = pos2(i_rd,1);

if P_ld < P_lu %adjust left sides
    pos_ld = [pos2(i_lu,1),pos2(i_ld,2),wh];
    pos_lu = [pos2(i_lu,1),pos2(i_lu,2),wh];
    set(s(i_ld),'Position',pos_ld);
    set(s(i_lu),'Position',pos_lu);
else 
    pos_lu = [pos2(i_ld,1),pos2(i_lu,2),wh];
    pos_ld = [pos2(i_ld,1),pos2(i_ld,2),wh];
    set(s(i_lu),'Position',pos_lu);
    set(s(i_ld),'Position',pos_ld);
end%if

if P_rd < P_ru %adjust right sides
    pos_rd = [pos2(i_ru,1),pos2(i_rd,2),wh];
    pos_ru = [pos2(i_ru,1),pos2(i_ru,2),wh];
    set(s(i_rd),'Position',pos_rd);
    set(s(i_ru),'Position',pos_ru);
else 
    pos_ru = [pos2(i_rd,1),pos2(i_ru,2),wh];
    pos_rd = [pos2(i_rd,1),pos2(i_rd,2),wh];
    set(s(i_ru),'Position',pos_ru);
    set(s(i_rd),'Position',pos_rd);
end%if

elseif subplotpos == '3x2'    %%%%%%%%%%%%%%%%%%
    s = findobj(allchild(fig), 'flat', 'Type', 'axes');
cellPos = get(s,'OuterPosition');
pos = cell2mat(cellPos);
x = sort(pos(:,1));
y = sort(pos(:,2));

for i = 1:size(s,1) % Push the outerposition
if     (pos(i,1)==x(1) || pos(i,1)==x(2)||pos(i,1)==x(3)) && (pos(i,2)==y(1)||pos(i,2)==y(2)) % left down  
    set(s(i),'OuterPosition',[0,0,0.5,0.333]);
    i_ld = i;
elseif (pos(i,1)==x(1) || pos(i,1)==x(2)||pos(i,1)==x(3)) && (pos(i,2)==y(3)||pos(i,2)==y(4)) % left middle  
    set(s(i),'OuterPosition',[0,0.331,0.5,0.33]);
    i_lm = i;
elseif (pos(i,1)==x(1) || pos(i,1)==x(2)||pos(i,1)==x(3)) && (pos(i,2)==y(5)||pos(i,2)==y(6)) % left up  
    set(s(i),'OuterPosition',[0,0.662,0.5,0.33]);
    i_lu = i;
 
elseif (pos(i,1)==x(4)||pos(i,1)==x(5)||pos(i,1)==x(6)) && (pos(i,2)==y(1)||pos(i,2)==y(2)) % right down  
    set(s(i),'OuterPosition',[0.5,0,0.5,0.33]);
    i_rd = i;
elseif (pos(i,1)==x(4)||pos(i,1)==x(5)||pos(i,1)==x(6)) && (pos(i,2)==y(3)||pos(i,2)==y(4)) % right middle  
    set(s(i),'OuterPosition',[0.5,0.331,0.5,0.33]);
    i_rm = i;
elseif (pos(i,1)==x(4)||pos(i,1)==x(5)||pos(i,1)==x(6)) && (pos(i,2)==y(5)||pos(i,2)==y(6)) % right up 
    set(s(i),'OuterPosition',[0.5,0.662,0.5,0.33]);
    i_ru = i;
end%if
end%for

pos2 = cell2mat(get(s,'Position'));
wh = [min(pos2(:,3)),min(pos2(:,4))];
P_ld = pos2(i_ld,1); % pos on x axis
P_lm = pos2(i_lm,1);
P_lu = pos2(i_lu,1);
P_rd = pos2(i_rd,1);
P_rm = pos2(i_rm,1);
P_ru = pos2(i_ru,1);

%adjust left sides
if P_ld < P_lu && P_lm < P_lu %lu is largest
    pos_ld = [pos2(i_lu,1),pos2(i_ld,2),wh];
    pos_lm = [pos2(i_lu,1),pos2(i_lm,2),wh];
    pos_lu = [pos2(i_lu,1),pos2(i_lu,2),wh];
    set(s(i_ld),'Position',pos_ld);
    set(s(i_lm),'Position',pos_lm);
    set(s(i_lu),'Position',pos_lu);
elseif P_ld<P_lm && P_lu<P_lm %lm is largest
    pos_ld = [pos2(i_lm,1),pos2(i_ld,2),wh];
    pos_lm = [pos2(i_lm,1),pos2(i_lm,2),wh];
    pos_lu = [pos2(i_lm,1),pos2(i_lu,2),wh];
    set(s(i_ld),'Position',pos_ld);
    set(s(i_lm),'Position',pos_lm);
    set(s(i_lu),'Position',pos_lu);
else %ld is largest
    pos_ld = [pos2(i_ld,1),pos2(i_ld,2),wh];
    pos_lm = [pos2(i_ld,1),pos2(i_lm,2),wh];
    pos_lu = [pos2(i_ld,1),pos2(i_lu,2),wh];
    set(s(i_ld),'Position',pos_ld);
    set(s(i_lm),'Position',pos_lm);
    set(s(i_lu),'Position',pos_lu);
end%if

if P_rd < P_ru && P_rm < P_ru %ru is largest
    pos_rd = [pos2(i_ru,1),pos2(i_rd,2),wh];
    pos_rm = [pos2(i_ru,1),pos2(i_rm,2),wh];
    pos_ru = [pos2(i_ru,1),pos2(i_ru,2),wh];
    set(s(i_rd),'Position',pos_rd);
    set(s(i_rm),'Position',pos_rm);
    set(s(i_ru),'Position',pos_ru);
elseif P_rd<P_rm && P_ru<P_rm %rm is largest
    pos_rd = [pos2(i_rm,1),pos2(i_rd,2),wh];
    pos_rm = [pos2(i_rm,1),pos2(i_rm,2),wh];
    pos_ru = [pos2(i_rm,1),pos2(i_ru,2),wh];
    set(s(i_rd),'Position',pos_rd);
    set(s(i_rm),'Position',pos_rm);
    set(s(i_ru),'Position',pos_ru);
else %rd is largest
    pos_rd = [pos2(i_rd,1),pos2(i_rd,2),wh];
    pos_rm = [pos2(i_rd,1),pos2(i_rm,2),wh];
    pos_ru = [pos2(i_rd,1),pos2(i_ru,2),wh];
    set(s(i_rd),'Position',pos_rd);
    set(s(i_rm),'Position',pos_rm);
    set(s(i_ru),'Position',pos_ru);
end%if

elseif subplotpos == '3x3'    %%%%%%%%%%%%%%%%%%
    s = findobj(allchild(fig), 'flat', 'Type', 'axes');
cellPos = get(s,'OuterPosition');
pos = cell2mat(cellPos);
x = sort(pos(:,1));
y = sort(pos(:,2));

for i = 1:size(s,1) % Push the outerposition
if     (pos(i,1)==x(1) || pos(i,1)==x(2)||pos(i,1)==x(3)) && (pos(i,2)==y(1)||pos(i,2)==y(2)||pos(i,2)==y(3)) % left down  
    set(s(i),'OuterPosition',[0,0,0.33,0.33]);
    i_ld = i;
elseif (pos(i,1)==x(1) || pos(i,1)==x(2)||pos(i,1)==x(3)) && (pos(i,2)==y(4)||pos(i,2)==y(5)||pos(i,2)==y(6)) % left middle  
    set(s(i),'OuterPosition',[0,0.331,0.33,0.33]);
    i_lm = i;
elseif (pos(i,1)==x(1) || pos(i,1)==x(2)||pos(i,1)==x(3)) && (pos(i,2)==y(7)||pos(i,2)==y(8)||pos(i,2)==y(9)) % left up  
    set(s(i),'OuterPosition',[0,0.662,0.33,0.33]);
    i_lu = i;
    
    
elseif (pos(i,1)==x(4)||pos(i,1)==x(5)||pos(i,1)==x(6)) && (pos(i,2)==y(1)||pos(i,2)==y(2)||pos(i,2)==y(3)) % middle down  
    set(s(i),'OuterPosition',[0.331,0,0.33,0.33]);
    i_md = i;
elseif (pos(i,1)==x(4)||pos(i,1)==x(5)||pos(i,1)==x(6)) && (pos(i,2)==y(4)||pos(i,2)==y(5)||pos(i,2)==y(6)) % middle middle  
    set(s(i),'OuterPosition',[0.331,0.331,0.33,0.33]);
    i_mm = i;
elseif (pos(i,1)==x(4)||pos(i,1)==x(5)||pos(i,1)==x(6)) && (pos(i,2)==y(7)||pos(i,2)==y(8)||pos(i,2)==y(9))  % middle up 
    set(s(i),'OuterPosition',[0.331,0.662,0.33,0.33]);
    i_mu = i;

    
elseif  (pos(i,1)==x(7) || pos(i,1)==x(8)||pos(i,1)==x(9)) && (pos(i,2)==y(1)||pos(i,2)==y(2)||pos(i,2)==y(3)) % right down  
    set(s(i),'OuterPosition',[0.662,0,0.33,0.33]);
    i_rd = i;
elseif (pos(i,1)==x(7) || pos(i,1)==x(8)||pos(i,1)==x(9)) && (pos(i,2)==y(4)||pos(i,2)==y(5)||pos(i,2)==y(6)) % right middle  
    set(s(i),'OuterPosition',[0.662,0.331,0.33,0.33]);
    i_rm = i;
elseif (pos(i,1)==x(7) || pos(i,1)==x(8)||pos(i,1)==x(9)) && (pos(i,2)==y(7)||pos(i,2)==y(8)||pos(i,2)==y(9)) % right up  
    set(s(i),'OuterPosition',[0.662,0.662,0.33,0.33]);
    i_ru = i;
end%if


end%for

pos2 = cell2mat(get(s,'Position'));
wh = [min(pos2(:,3)),min(pos2(:,4))];
P_ld = pos2(i_ld,1);% pos on x axis
P_lm = pos2(i_lm,1);
P_lu = pos2(i_lu,1);
P_md = pos2(i_md,1);%
P_mm = pos2(i_mm,1);
P_mu = pos2(i_mu,1);
P_rd = pos2(i_rd,1);%
P_rm = pos2(i_rm,1);
P_ru = pos2(i_ru,1);

%adjust left sides
if P_ld < P_lu && P_lm < P_lu %lu is largest
    pos_ld = [pos2(i_lu,1),pos2(i_ld,2),wh];
    pos_lm = [pos2(i_lu,1),pos2(i_lm,2),wh];
    pos_lu = [pos2(i_lu,1),pos2(i_lu,2),wh];
    set(s(i_ld),'Position',pos_ld);
    set(s(i_lm),'Position',pos_lm);
    set(s(i_lu),'Position',pos_lu);
elseif P_ld<P_lm && P_lu<P_lm %lm is largest
    pos_ld = [pos2(i_lm,1),pos2(i_ld,2),wh];
    pos_lm = [pos2(i_lm,1),pos2(i_lm,2),wh];
    pos_lu = [pos2(i_lm,1),pos2(i_lu,2),wh];
    set(s(i_ld),'Position',pos_ld);
    set(s(i_lm),'Position',pos_lm);
    set(s(i_lu),'Position',pos_lu);
else %ld is largest
    pos_ld = [pos2(i_ld,1),pos2(i_ld,2),wh];
    pos_lm = [pos2(i_ld,1),pos2(i_lm,2),wh];
    pos_lu = [pos2(i_ld,1),pos2(i_lu,2),wh];
    set(s(i_ld),'Position',pos_ld);
    set(s(i_lm),'Position',pos_lm);
    set(s(i_lu),'Position',pos_lu);
end%if


%adjust middle
if P_md < P_mu && P_mm < P_mu %mu is largest
    pos_md = [pos2(i_mu,1),pos2(i_md,2),wh];
    pos_mm = [pos2(i_mu,1),pos2(i_mm,2),wh];
    pos_mu = [pos2(i_mu,1),pos2(i_mu,2),wh];
    set(s(i_md),'Position',pos_md);
    set(s(i_mm),'Position',pos_mm);
    set(s(i_mu),'Position',pos_mu);
elseif P_md<P_mm && P_mu<P_mm %mm is largest
    pos_md = [pos2(i_mm,1),pos2(i_md,2),wh];
    pos_mm = [pos2(i_mm,1),pos2(i_mm,2),wh];
    pos_mu = [pos2(i_mm,1),pos2(i_mu,2),wh];
    set(s(i_md),'Position',pos_md);
    set(s(i_mm),'Position',pos_mm);
    set(s(i_mu),'Position',pos_mu);
else %ld is largest
    pos_md = [pos2(i_md,1),pos2(i_md,2),wh];
    pos_mm = [pos2(i_md,1),pos2(i_mm,2),wh];
    pos_mu = [pos2(i_md,1),pos2(i_mu,2),wh];
    set(s(i_md),'Position',pos_md);
    set(s(i_mm),'Position',pos_mm);
    set(s(i_mu),'Position',pos_mu);
end%if

%adjust right sides
if P_rd < P_ru && P_rm < P_ru %ru is largest
    pos_rd = [pos2(i_ru,1),pos2(i_rd,2),wh];
    pos_rm = [pos2(i_ru,1),pos2(i_rm,2),wh];
    pos_ru = [pos2(i_ru,1),pos2(i_ru,2),wh];
    set(s(i_rd),'Position',pos_rd);
    set(s(i_rm),'Position',pos_rm);
    set(s(i_ru),'Position',pos_ru);
elseif P_rd<P_rm && P_ru<P_rm %rm is largest
    pos_rd = [pos2(i_rm,1),pos2(i_rd,2),wh];
    pos_rm = [pos2(i_rm,1),pos2(i_rm,2),wh];
    pos_ru = [pos2(i_rm,1),pos2(i_ru,2),wh];
    set(s(i_rd),'Position',pos_rd);
    set(s(i_rm),'Position',pos_rm);
    set(s(i_ru),'Position',pos_ru);
else %rd is largest
    pos_rd = [pos2(i_rd,1),pos2(i_rd,2),wh];
    pos_rm = [pos2(i_rd,1),pos2(i_rm,2),wh];
    pos_ru = [pos2(i_rd,1),pos2(i_ru,2),wh];
    set(s(i_rd),'Position',pos_rd);
    set(s(i_rm),'Position',pos_rm);
    set(s(i_ru),'Position',pos_ru);
end%if


end%if %subplot

end%fun