addpath('C:\Users\NOTADAS\Downloads\casadi-windows-matlabR2016a-v3.4.5');
import casadi.*
n_r = 12;
n_x = 12;
scaling_factor = 1e-2;

%% Definition of CasADi variables :
% N1 = SX.sym('N1',3*n_r*n_x,1);                   % States     
N1 = X(ns_gs1+1:ns_gs1+ns_hc);
U_hc = U(nu_gs1+1:nu_gs1+nu_hc);
D_hc = [U_gs1(3)/3;
    U_gs1(3)*(1-WC_L_gs1)/U_gs1(3)];


X_dots_hc = X_dot(ns_gs1+1:ns_gs1+ns_hc);
N_dot = reshape(X_dots_hc(1:n_x*n_r),n_x,n_r)*scaling_factor;
dd_dot = reshape(X_dots_hc(n_x*n_r+1:2*n_x*n_r),n_x,n_r)*1e-6;
v_theta_dot = reshape(X_dots_hc(2*n_x*n_r+1:3*n_x*n_r),n_x,n_r);

F_in = D_hc(1);
e_in = D_hc(2);
F_over = U_hc*F_in;


%% INITIALISATION

N = reshape(N1(1:n_r*n_x),n_r,n_x)*scaling_factor;   % Number of droplets
dd = reshape(N1(n_r*n_x+1:2*n_r*n_x),n_r,n_x)*1e-6;  % Diameter of droplets
v_theta = reshape(N1(2*n_r*n_x+1:3*n_r*n_x),n_r,n_x);% Angular velocity

F_under = F_in - F_over; 
R_o = 0.05;                                          % Radius pipe
R_i = 0.025;                                         % Radius of oil pipe
R_c = 0.25*R_o; % Rankine vortex    (Radius of solidbody rotation)
C_decay = 0.04; % Swirl decay
L = 1.7; % Length of the separator
dL = L/n_x;  % Width of ring
v_zb = F_in/pi/R_o^2;  % Feed velocity
Omega = 2.5; % Swirl number
v_theta_max = Omega * v_zb; % maximum angular velocity

% if v_theta_max <= 4.45
%     dd_in = (-107*v_theta_max + 600)*1e-6;
% else
%     dd_in = (-8*v_theta_max + 160)*1e-6;
% end


dd_in1 = max(v_theta_max - 4.45,0)/(v_theta_max - 4.45)*(-8*v_theta_max + 160)*1e-6;
dd_in2 = max(4.45 - v_theta_max ,0)/(4.45 - v_theta_max)*(-107*v_theta_max + 600)*1e-6;
dd_in = max(dd_in1,dd_in2);


% Vd = pi*dd_in^3/6;
% nd_in = e_in/Vd;

%% CALCULATE CHANGE IN ANGULAR VELOCITIES (v_theta_dot)

% START OF PIPE!
% v_theta_dot = zeros(n_r,n_x);
 j = 1;
 i = 1; %smallest ring
v_theta_inner = 0;
v_theta_outer = (v_theta(i,j)*(sqrt(i/n_r)-sqrt((i-1)/n_r)) + v_theta(i+1,j)*(sqrt((i+1)/n_r)-sqrt((i)/n_r)))/(sqrt((i+1)/n_r)-sqrt((i-1)/n_r));
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i+1,j));
v_theta_i = v_theta_in(i,v_theta_max,R_c,R_o,n_r);
v_theta_dot(i,j) = -v_x_left*(v_theta(i,j) - v_theta_i)/(dL/2) - C_decay/2/R_o*v_theta(i,j)*v_x_left; 
 
for i = 2:n_r-1 % rings in pipe
v_theta_inner = (v_theta(i-1,j)*(sqrt((i-1)/n_r)-sqrt((i-2)/n_r)) + v_theta(i,j)*(sqrt((i)/n_r)-sqrt((i-1)/n_r)))/(sqrt((i)/n_r)-sqrt((i-2)/n_r));
v_theta_outer = (v_theta(i,j)*(sqrt(i/n_r)-sqrt((i-1)/n_r)) + v_theta(i+1,j)*(sqrt((i+1)/n_r)-sqrt((i)/n_r)))/(sqrt((i+1)/n_r)-sqrt((i-1)/n_r));   
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i+1,j));
v_theta_i = v_theta_in(i,v_theta_max,R_c,R_o,n_r);
v_theta_dot(i,j) = -v_x_left*(v_theta(i,j) - v_theta_i)/(dL/2) - C_decay/2/R_o*v_theta(i,j)*v_x_left;
end

i = n_r; % largest ring
v_theta_inner = (v_theta(i-1,j)*(sqrt((i-1)/n_r)-sqrt((i-2)/n_r)) + v_theta(i,j)*(sqrt((i)/n_r)-sqrt((i-1)/n_r)))/(sqrt((i)/n_r)-sqrt((i-2)/n_r));
v_theta_outer = 0;   
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i,j));
v_theta_i = v_theta_in(i,v_theta_max,R_c,R_o,n_r);
v_theta_dot(i,j) = -v_x_left*(v_theta(i,j) - v_theta_i)/(dL/2) - C_decay/2/R_o*v_theta(i,j)*v_x_left;

% REST OF PIPE!
for j = 2:n_x
     i = 1;
v_theta_inner = 0;
v_theta_outer = (v_theta(i,j)*(sqrt(i/n_r)-sqrt((i-1)/n_r)) + v_theta(i+1,j)*(sqrt((i+1)/n_r)-sqrt((i)/n_r)))/(sqrt((i+1)/n_r)-sqrt((i-1)/n_r));
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i+1,j));
v_theta_dot(i,j) = -v_x_left*(v_theta(i,j) - v_theta(i,j-1))/(dL) - C_decay/2/R_o*v_theta(i,j)*v_x_left;     
     for i = 2:n_r-1
v_theta_inner = (v_theta(i-1,j)*(sqrt((i-1)/n_r)-sqrt((i-2)/n_r)) + v_theta(i,j)*(sqrt((i)/n_r)-sqrt((i-1)/n_r)))/(sqrt((i)/n_r)-sqrt((i-2)/n_r));
v_theta_outer = (v_theta(i,j)*(sqrt(i/n_r)-sqrt((i-1)/n_r)) + v_theta(i+1,j)*(sqrt((i+1)/n_r)-sqrt((i)/n_r)))/(sqrt((i+1)/n_r)-sqrt((i-1)/n_r));   
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i+1,j));
v_theta_dot(i,j) = -v_x_left*(v_theta(i,j) - v_theta(i,j-1))/(dL) - C_decay/2/R_o*v_theta(i,j)*v_x_left;
     end
     i = n_r;
v_theta_inner = (v_theta(i-1,j)*(sqrt((i-1)/n_r)-sqrt((i-2)/n_r)) + v_theta(i,j)*(sqrt((i)/n_r)-sqrt((i-1)/n_r)))/(sqrt((i)/n_r)-sqrt((i-2)/n_r));
v_theta_outer = 0;   
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i,j));
v_theta_dot(i,j) = -v_x_left*(v_theta(i,j) - v_theta(i,j-1))/(dL) - C_decay/2/R_o*v_theta(i,j)*v_x_left;
end


%% CALCULATE CHANGE IN DROPLET DIAMETERS (dd_dot)
% dd_dot = zeros(n_r,n_x);
 j = 1;
 i = 1;
v_theta_inner = 0;
v_theta_outer = (v_theta(i,j)*(sqrt(i/n_r)-sqrt((i-1)/n_r)) + v_theta(i+1,j)*(sqrt((i+1)/n_r)-sqrt((i)/n_r)))/(sqrt((i+1)/n_r)-sqrt((i-1)/n_r));
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i+1,j));
dd_dot(i,j) = -v_x_left*(dd(i,j) - dd_in)/(dL/2); 
 
for i = 2:n_r-1
v_theta_inner = (v_theta(i-1,j)*(sqrt((i-1)/n_r)-sqrt((i-2)/n_r)) + v_theta(i,j)*(sqrt((i)/n_r)-sqrt((i-1)/n_r)))/(sqrt((i)/n_r)-sqrt((i-2)/n_r));
v_theta_outer = (v_theta(i,j)*(sqrt(i/n_r)-sqrt((i-1)/n_r)) + v_theta(i+1,j)*(sqrt((i+1)/n_r)-sqrt((i)/n_r)))/(sqrt((i+1)/n_r)-sqrt((i-1)/n_r));   
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i+1,j));
dd_dot(i,j) = -v_x_left*(dd(i,j) - dd_in)/(dL/2);
end
i = n_r;
v_theta_inner = (v_theta(i-1,j)*(sqrt((i-1)/n_r)-sqrt((i-2)/n_r)) + v_theta(i,j)*(sqrt((i)/n_r)-sqrt((i-1)/n_r)))/(sqrt((i)/n_r)-sqrt((i-2)/n_r));
v_theta_outer = 0;   
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i,j));
dd_dot(i,j) = -v_x_left*(dd(i,j) - dd_in)/(dL/2);


for j = 2:n_x
     i = 1;
v_theta_inner = 0;
v_theta_outer = (v_theta(i,j)*(sqrt(i/n_r)-sqrt((i-1)/n_r)) + v_theta(i+1,j)*(sqrt((i+1)/n_r)-sqrt((i)/n_r)))/(sqrt((i+1)/n_r)-sqrt((i-1)/n_r));
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i+1,j));
dd_dot(i,j) = -v_x_left*(dd(i,j) - dd(i,j-1))/(dL);     
     for i = 2:n_r-1
v_theta_inner = (v_theta(i-1,j)*(sqrt((i-1)/n_r)-sqrt((i-2)/n_r)) + v_theta(i,j)*(sqrt((i)/n_r)-sqrt((i-1)/n_r)))/(sqrt((i)/n_r)-sqrt((i-2)/n_r));
v_theta_outer = (v_theta(i,j)*(sqrt(i/n_r)-sqrt((i-1)/n_r)) + v_theta(i+1,j)*(sqrt((i+1)/n_r)-sqrt((i)/n_r)))/(sqrt((i+1)/n_r)-sqrt((i-1)/n_r));   
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i+1,j));
dd_dot(i,j) = -v_x_left*(dd(i,j) - dd(i,j-1))/(dL);
     end
     i = n_r;
v_theta_inner = (v_theta(i-1,j)*(sqrt((i-1)/n_r)-sqrt((i-2)/n_r)) + v_theta(i,j)*(sqrt((i)/n_r)-sqrt((i-1)/n_r)))/(sqrt((i)/n_r)-sqrt((i-2)/n_r));
v_theta_outer = 0;   
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i,j));
dd_dot(i,j) = -v_x_left*(dd(i,j) - dd(i,j-1))/(dL);
 end


%% Calculate change in concentration: (N_dot)
j = 1;
i = 1;
v_theta_inner = 0;
v_theta_outer = (v_theta(i,j)*(sqrt(i/n_r)-sqrt((i-1)/n_r)) + v_theta(i+1,j)*(sqrt((i+1)/n_r)-sqrt((i)/n_r)))/(sqrt((i+1)/n_r)-sqrt((i-1)/n_r));
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i+1,j));
N_dot(i,j) = Ac_outer*v_r_outer*N(i+1,j)/dV + (v_x_left*e_in - v_x_right*N(i,j))/dL;
% N_dot(i,j) = Ac_outer*v_r_outer*N(i+1,j)/dV*min(max((1- Vd*N(i,j)),0),1) + (v_x_left*nd_in - v_x_right*N(i,j)*min(max((1- Vd*N(i,j+1)),0),1))/dL;
for i = 2:n_r-1
v_theta_inner = (v_theta(i-1,j)*(sqrt((i-1)/n_r)-sqrt((i-2)/n_r)) + v_theta(i,j)*(sqrt((i)/n_r)-sqrt((i-1)/n_r)))/(sqrt((i)/n_r)-sqrt((i-2)/n_r));
v_theta_outer = (v_theta(i,j)*(sqrt(i/n_r)-sqrt((i-1)/n_r)) + v_theta(i+1,j)*(sqrt((i+1)/n_r)-sqrt((i)/n_r)))/(sqrt((i+1)/n_r)-sqrt((i-1)/n_r));   
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i+1,j));
N_dot(i,j) = (Ac_outer*v_r_outer*N(i+1,j) - Ac_inner*v_r_inner*N(i,j))/dV + (v_x_left*e_in - v_x_right*N(i,j))/dL;
% N_dot(i,j) = (Ac_outer*v_r_outer*N(i+1,j)*min(max((1- Vd*N(i,j)),0),1) - Ac_inner*v_r_inner*N(i,j)*min(max((1- Vd*N(i-1,j)),0),1))/dV + (v_x_left*nd_in - v_x_right*N(i,j)*min(max((1- Vd*N(i,j+1)),0),1))/dL;
end
i = n_r;
v_theta_inner = (v_theta(i-1,j)*(sqrt((i-1)/n_r)-sqrt((i-2)/n_r)) + v_theta(i,j)*(sqrt((i)/n_r)-sqrt((i-1)/n_r)))/(sqrt((i)/n_r)-sqrt((i-2)/n_r));
v_theta_outer = 0;   
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i,j));
N_dot(i,j) = -(Ac_inner*v_r_inner*N(i,j))/dV + (v_x_left*e_in - v_x_right*N(i,j))/dL;
% N_dot(i,j) = -(Ac_inner*v_r_inner*N(i,j))/dV *min(max((1- Vd*N(i-1,j)),0),1) + (v_x_left*nd_in - v_x_right*N(i,j)*min(max((1- Vd*N(i,j+1)),0),1))/dL;

for j = 2:n_x

i = 1;
v_theta_inner = 0;
v_theta_outer = (v_theta(i,j)*(sqrt(i/n_r)-sqrt((i-1)/n_r)) + v_theta(i+1,j)*(sqrt((i+1)/n_r)-sqrt((i)/n_r)))/(sqrt((i+1)/n_r)-sqrt((i-1)/n_r));
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i+1,j));
N_dot(i,j) = Ac_outer*v_r_outer*N(i+1,j)/dV + (v_x_left*N(i,j-1) - v_x_right*N(i,j))/dL;
% N_dot(i,j) = Ac_outer*v_r_outer*N(i+1,j)/dV *min(max((1- Vd*N(i,j)),0),1) + (v_x_left*N(i,j-1)*min(max((1- Vd*N(i,j)),0),1) - v_x_right*N(i,j)*min(max((1- Vd*N(i,j+1)),0),1))/dL;

for i = 2:n_r-1
v_theta_inner = (v_theta(i-1,j)*(sqrt((i-1)/n_r)-sqrt((i-2)/n_r)) + v_theta(i,j)*(sqrt((i)/n_r)-sqrt((i-1)/n_r)))/(sqrt((i)/n_r)-sqrt((i-2)/n_r));
v_theta_outer = (v_theta(i,j)*(sqrt(i/n_r)-sqrt((i-1)/n_r)) + v_theta(i+1,j)*(sqrt((i+1)/n_r)-sqrt((i)/n_r)))/(sqrt((i+1)/n_r)-sqrt((i-1)/n_r));   
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i+1,j));
N_dot(i,j) = (Ac_outer*v_r_outer*N(i+1,j)-Ac_inner*v_r_inner*N(i,j))/dV + (v_x_left*N(i,j-1) - v_x_right*N(i,j))/dL;  
% N_dot(i,j) = (Ac_outer*v_r_outer*N(i+1,j)*min(max((1- Vd*N(i,j)),0),1)-Ac_inner*v_r_inner*N(i,j)*min(max((1- Vd*N(i-1,j)),0),1))/dV + (v_x_left*N(i,j-1)*min(max((1- Vd*N(i,j)),0),1) - v_x_right*N(i,j)*min(max((1- Vd*N(i,j+1)),0),1))/dL; 
end

i = n_r;
v_theta_inner = (v_theta(i-1,j)*(sqrt((i-1)/n_r)-sqrt((i-2)/n_r)) + v_theta(i,j)*(sqrt((i)/n_r)-sqrt((i-1)/n_r)))/(sqrt((i)/n_r)-sqrt((i-2)/n_r));
v_theta_outer = 0;   
[Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,R_i,R_o,L,n_r,n_x,F_in,F_over,v_theta_inner,v_theta_outer,dd(i,j),dd(i,j));
N_dot(i,j) = -(Ac_inner*v_r_inner*N(i,j))/dV + (v_x_left*N(i,j-1) - v_x_right*N(i,j))/dL;
% N_dot(i,j) = -(Ac_inner*v_r_inner*N(i,j))/dV*min(max((1- Vd*N(i-1,j)),0),1)+ (v_x_left*N(i,j-1)*min(max((1- Vd*N(i,j)),0),1) - v_x_right*N(i,j)*min(max((1- Vd*N(i,j+1)),0),1))/dL;
end

%%
% j = n_x;
% 
% i = 1;
% [Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,j,R_i,R_o,L,n_r,n_x,F_in,F_over,Omega,dd);
% N_dot(i,j) = Ac_outer*v_r_outer*N(i+1,j)/dV + (v_x_left*N(i,j-1) - v_x_right*N(i,j))/dL;
% % N_dot(i,j) = Ac_outer*v_r_outer*N(i+1,j)/dV *min(max((1- Vd*N(i,j)),0),1) + (v_x_left*N(i,j-1)*min(max((1- Vd*N(i,j)),0),1)- v_x_right*N(i,j))/dL;
% 
% for i = 2:n_r-1
% [Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,j,R_i,R_o,L,n_r,n_x,F_in,F_over,Omega,dd);
% N_dot(i,j) = (Ac_outer*v_r_outer*N(i+1,j)-Ac_inner*v_r_inner*N(i,j))/dV + (v_x_left*N(i,j-1) - v_x_right*N(i,j))/dL;  
% % N_dot(i,j) = (Ac_outer*v_r_outer*N(i+1,j)*min(max((1- Vd*N(i,j)),0),1)-Ac_inner*v_r_inner*N(i,j)*min(max((1- Vd*N(i-1,j)),0),1))/dV + (v_x_left*N(i,j-1)*min(max((1- Vd*N(i,j)),0),1) - v_x_right*N(i,j))/dL; 
% end
% 
% i = n_r;
% [Ac_outer,Ac_inner,Ax,v_r_inner,v_r_outer,v_x_left,v_x_right,dV] = area_vel_vol(i,j,R_i,R_o,L,n_r,n_x,F_in,F_over,Omega,dd);
% N_dot(i,j) = -(Ac_inner*v_r_inner*N(i,j))/dV + (v_x_left*N(i,j-1) - v_x_right*N(i,j))/dL;
% % N_dot(i,j) = -(Ac_inner*v_r_inner*N(i,j))/dV*min(max((1- Vd*N(i-1,j)),0),1) + (v_x_left*N(i,j-1)*min(max((1- Vd*N(i,j)),0),1) - v_x_right*N(i,j))/dL;


e_under_ideal = 0;
e_over_ideal = 0;

%%
j = n_x;
for i = 4:n_r
e_under_ideal = e_under_ideal  + N(i,j)/9; 
end

for i = 1:3
e_over_ideal = e_over_ideal  +  N(i,j)/3; 
end

%%
k_reen = 1e-6;
q_reen = k_reen*(F_under/pi/(R_o^2-R_i^2) - F_over/pi/R_i^2);
e_under_real = ((F_under - q_reen)*e_under_ideal+(q_reen)*e_over_ideal)/F_under;
e_over_real = ((F_over - q_reen)*e_over_ideal+(q_reen)*e_under_ideal)/F_over;


dots = [reshape(N_dot,n_r*n_x,1)/scaling_factor; reshape(dd_dot,n_r*n_x,1)/1e-6; reshape(v_theta_dot,n_r*n_x,1); e_under_ideal*1e6; e_over_ideal*1e6; e_under_real*1e6];
dots_hc = dots(1:end-3);
ppmOut_hc = e_under_real*1e6;

% output_gs2 = [U_gs2(1)*3600;WC_R_gs2*100;U_gs2(2)*3600;WC_L_gs2*1e6];
output_hc = [F_under*3*3600;e_under_real*1e6;F_over*3*3600; e_over_real*100];
